@@ -1,7 +1,9 @@
+// Copyright (c) 2021 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 import '@patternfly/react-core/dist/styles/base.css'
 import React, { Fragment, useState, useEffect } from 'react'
 import { ButtonVariant, ModalVariant } from '@patternfly/react-core'
-import { AcmModal, AcmButton, AcmAlert } from '@stolostron/ui-components'
+import { AcmModal, AcmButton, AcmAlert } from '@open-cluster-management/ui-components'
 import { useTranslation } from 'react-i18next'
 import { SavedSearchesDocument, useDeleteSearchMutation } from '../../../../search-sdk/search-sdk'
 import { searchClient } from '../../../../search-sdk/search-client'
@@ -41,14 +43,15 @@ export const DeleteSearchModal = (props: any) => {
                 variant={ModalVariant.medium}
                 isOpen={props.deleteSearch !== undefined}
                 title={t('search.modal.delete.search.title')}
+                titleIconVariant={'warning'}
                 onClose={props.onClose}
                 actions={[
-                    <AcmButton key="cancel" variant={ButtonVariant.link} onClick={props.onClose}>
-                        {t('search.modal.delete.search.action.cancel')}
-                    </AcmButton>,
                     <AcmButton key="confirm" variant={ButtonVariant.danger} onClick={() => deleteSearch()}>
                         {t('search.modal.delete.search.action.delete')}
                     </AcmButton>,
+                    <AcmButton key="cancel" variant={ButtonVariant.link} onClick={props.onClose}>
+                        {t('search.modal.delete.search.action.cancel')}
+                    </AcmButton>,
                 ]}
             >
                 {isError && (
@@ -59,7 +62,7 @@ export const DeleteSearchModal = (props: any) => {
                         title={error!.message}
                     />
                 )}
-                <p>{t('search.modal.delete.search.text')}</p>
+                <p>{t('search.modal.delete.search.text', { savedSearchName: props.deleteSearch?.name })}</p>
             </AcmModal>
         </Fragment>
     )
