@@ -1,4 +1,6 @@
-import { DropdownSuggestionsProps } from '@stolostron/ui-components'
+// Copyright (c) 2021 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
+import { DropdownSuggestionsProps } from '@open-cluster-management/ui-components'
 
 const operators = ['=', '<', '>', '<=', '>=', '!=', '!']
 const dateValues = ['hour', 'day', 'week', 'month', 'year']
@@ -114,8 +116,15 @@ export const getSearchCompleteString = (searchQuery: string) => {
     const queryTags = searchQuery.split(' ')
     if (queryTags[queryTags.length - 1].endsWith(':')) {
         return queryTags[queryTags.length - 1].replace(':', '')
-    } else if (operators.some((op) => queryTags[queryTags.length - 1].endsWith(op))) {
-        return queryTags[queryTags.length - 1].substring(0, queryTags[queryTags.length - 1].length - 2)
+    } else if (
+        operators.some(
+            (op) => queryTags[queryTags.length - 1].substring(queryTags[queryTags.length - 1].length - op.length) === op
+        )
+    ) {
+        const operator = operators.filter(
+            (op) => queryTags[queryTags.length - 1].substring(queryTags[queryTags.length - 1].length - op.length) === op
+        )
+        return queryTags[queryTags.length - 1].replace(':', '').replace(operator[operator.length - 1], '')
     }
     return ''
 }
