@@ -8,17 +8,25 @@ var __decorate = (this && this.__decorate) || function (decorators, target, key,
     else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
     return c > 3 && r && Object.defineProperty(target, key, r), r;
 };
+var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
+    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
+    return new (P || (P = Promise))(function (resolve, reject) {
+        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
+        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
+        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
+        step((generator = generator.apply(thisArg, _arguments || [])).next());
+    });
+};
 import './list.css';
 import { dispose, DisposableStore } from '../../../common/lifecycle.js';
 import { isNumber } from '../../../common/types.js';
-import { range, firstIndex, binarySearch } from '../../../common/arrays.js';
+import { range, binarySearch, firstOrDefault } from '../../../common/arrays.js';
 import { memoize } from '../../../common/decorators.js';
-import * as DOM from '../../dom.js';
 import * as platform from '../../../common/platform.js';
 import { Gesture } from '../../touch.js';
 import { StandardKeyboardEvent } from '../../keyboardEvent.js';
 import { Event, Emitter, EventBufferer } from '../../../common/event.js';
-import { domEvent } from '../../event.js';
+import { domEvent, stopEvent } from '../../event.js';
 import { ListError } from './list.js';
 import { ListView } from './listView.js';
 import { Color } from '../../../common/color.js';
@@ -27,6 +35,8 @@ import { CombinedSpliceable } from './splice.js';
 import { clamp } from '../../../common/numbers.js';
 import { matchesPrefix } from '../../../common/filters.js';
 import { alert } from '../aria/aria.js';
+import { createStyleSheet } from '../../dom.js';
+import { timeout } from '../../../common/async.js';
 class TraitRenderer {
     constructor(trait) {
         this.trait = trait;
@@ -39,7 +49,7 @@ class TraitRenderer {
         return container;
     }
     renderElement(element, index, templateData) {
-        const renderedElementIndex = firstIndex(this.renderedElements, el => el.templateData === templateData);
+        const renderedElementIndex = this.renderedElements.findIndex(el => el.templateData === templateData);
         if (renderedElementIndex >= 0) {
             const rendered = this.renderedElements[renderedElementIndex];
             this.trait.unrender(templateData);
@@ -74,7 +84,7 @@ class TraitRenderer {
         }
     }
     disposeTemplate(templateData) {
-        const index = firstIndex(this.renderedElements, el => el.templateData === templateData);
+        const index = this.renderedElements.findIndex(el => el.templateData === templateData);
         if (index < 0) {
             return;
         }
@@ -105,10 +115,10 @@ class Trait {
         this._set(indexes, indexes);
     }
     renderIndex(index, container) {
-        DOM.toggleClass(container, this._trait, this.contains(index));
+        container.classList.toggle(this._trait, this.contains(index));
     }
     unrender(container) {
-        DOM.removeClass(container, this._trait);
+        container.classList.remove(this._trait);
     }
     /**
      * Sets the indexes which should have this trait.
@@ -183,10 +193,10 @@ export function isInputElement(e) {
     return e.tagName === 'INPUT' || e.tagName === 'TEXTAREA';
 }
 export function isMonacoEditor(e) {
-    if (DOM.hasClass(e, 'monaco-editor')) {
+    if (e.classList.contains('monaco-editor')) {
         return true;
     }
-    if (DOM.hasClass(e, 'monaco-list')) {
+    if (e.classList.contains('monaco-list')) {
         return false;
     }
     if (!e.parentElement) {
@@ -253,10 +263,12 @@ class KeyboardController {
         this.view.domNode.focus();
     }
     onEscape(e) {
-        e.preventDefault();
-        e.stopPropagation();
-        this.list.setSelection([], e.browserEvent);
-        this.view.domNode.focus();
+        if (this.list.getSelection().length) {
+            e.preventDefault();
+            e.stopPropagation();
+            this.list.setSelection([], e.browserEvent);
+            this.view.domNode.focus();
+        }
     }
     dispose() {
         this.disposables.dispose();
@@ -482,22 +494,21 @@ export class MouseController {
         if (isInputElement(e.browserEvent.target) || isMonacoEditor(e.browserEvent.target)) {
             return;
         }
-        let reference = this.list.getFocus()[0];
-        const selection = this.list.getSelection();
-        reference = reference === undefined ? selection[0] : reference;
         const focus = e.index;
         if (typeof focus === 'undefined') {
             this.list.setFocus([], e.browserEvent);
             this.list.setSelection([], e.browserEvent);
+            this.list.setAnchor(undefined);
             return;
         }
         if (this.multipleSelectionSupport && this.isSelectionRangeChangeEvent(e)) {
-            return this.changeSelection(e, reference);
+            return this.changeSelection(e);
         }
         if (this.multipleSelectionSupport && this.isSelectionChangeEvent(e)) {
-            return this.changeSelection(e, reference);
+            return this.changeSelection(e);
         }
         this.list.setFocus([focus], e.browserEvent);
+        this.list.setAnchor(focus);
         if (!isMouseRightClick(e.browserEvent)) {
             this.list.setSelection([focus], e.browserEvent);
         }
@@ -513,24 +524,32 @@ export class MouseController {
         const focus = this.list.getFocus();
         this.list.setSelection(focus, e.browserEvent);
     }
-    changeSelection(e, reference) {
+    changeSelection(e) {
         const focus = e.index;
-        if (this.isSelectionRangeChangeEvent(e) && reference !== undefined) {
-            const min = Math.min(reference, focus);
-            const max = Math.max(reference, focus);
+        let anchor = this.list.getAnchor();
+        if (this.isSelectionRangeChangeEvent(e)) {
+            if (typeof anchor === 'undefined') {
+                const currentFocus = this.list.getFocus()[0];
+                anchor = currentFocus !== null && currentFocus !== void 0 ? currentFocus : focus;
+                this.list.setAnchor(anchor);
+            }
+            const min = Math.min(anchor, focus);
+            const max = Math.max(anchor, focus);
             const rangeSelection = range(min, max + 1);
             const selection = this.list.getSelection();
-            const contiguousRange = getContiguousRangeContaining(disjunction(selection, [reference]), reference);
+            const contiguousRange = getContiguousRangeContaining(disjunction(selection, [anchor]), anchor);
             if (contiguousRange.length === 0) {
                 return;
             }
             const newSelection = disjunction(rangeSelection, relativeComplement(selection, contiguousRange));
             this.list.setSelection(newSelection, e.browserEvent);
+            this.list.setFocus([focus], e.browserEvent);
         }
         else if (this.isSelectionSingleChangeEvent(e)) {
             const selection = this.list.getSelection();
             const newSelection = selection.filter(i => i !== focus);
             this.list.setFocus([focus]);
+            this.list.setAnchor(focus);
             if (selection.length === newSelection.length) {
                 this.list.setSelection([...newSelection, focus], e.browserEvent);
             }
@@ -585,6 +604,10 @@ export class DefaultStyleController {
 				.monaco-list${suffix}:focus .monaco-list-row.selected.focused { color: ${styles.listFocusAndSelectionForeground}; }
 			`);
         }
+        if (styles.listInactiveFocusForeground) {
+            content.push(`.monaco-list${suffix} .monaco-list-row.focused { color:  ${styles.listInactiveFocusForeground}; }`);
+            content.push(`.monaco-list${suffix} .monaco-list-row.focused:hover { color:  ${styles.listInactiveFocusForeground}; }`); // overwrite :hover style in this case!
+        }
         if (styles.listInactiveFocusBackground) {
             content.push(`.monaco-list${suffix} .monaco-list-row.focused { background-color:  ${styles.listInactiveFocusBackground}; }`);
             content.push(`.monaco-list${suffix} .monaco-list-row.focused:hover { background-color:  ${styles.listInactiveFocusBackground}; }`); // overwrite :hover style in this case!
@@ -597,7 +620,7 @@ export class DefaultStyleController {
             content.push(`.monaco-list${suffix} .monaco-list-row.selected { color: ${styles.listInactiveSelectionForeground}; }`);
         }
         if (styles.listHoverBackground) {
-            content.push(`.monaco-list${suffix}:not(.drop-target) .monaco-list-row:hover:not(.selected):not(.focused) { background-color:  ${styles.listHoverBackground}; }`);
+            content.push(`.monaco-list${suffix}:not(.drop-target) .monaco-list-row:hover:not(.selected):not(.focused) { background-color: ${styles.listHoverBackground}; }`);
         }
         if (styles.listHoverForeground) {
             content.push(`.monaco-list${suffix} .monaco-list-row:hover:not(.selected):not(.focused) { color:  ${styles.listHoverForeground}; }`);
@@ -636,10 +659,14 @@ export class DefaultStyleController {
         if (styles.listMatchesShadow) {
             content.push(`.monaco-list-type-filter { box-shadow: 1px 1px 1px ${styles.listMatchesShadow}; }`);
         }
-        const newStyles = content.join('\n');
-        if (newStyles !== this.styleElement.innerHTML) {
-            this.styleElement.innerHTML = newStyles;
+        if (styles.tableColumnsBorder) {
+            content.push(`
+				.monaco-table:hover > .monaco-split-view2,
+				.monaco-table:hover > .monaco-split-view2 .monaco-sash.vertical::before {
+					border-color: ${styles.tableColumnsBorder};
+			}`);
         }
+        this.styleElement.textContent = content.join('\n');
     }
 }
 const defaultStyles = {
@@ -651,7 +678,8 @@ const defaultStyles = {
     listInactiveSelectionBackground: Color.fromHex('#3F3F46'),
     listHoverBackground: Color.fromHex('#2A2D2E'),
     listDropBackground: Color.fromHex('#383B3D'),
-    treeIndentGuidesStroke: Color.fromHex('#a9a9a9')
+    treeIndentGuidesStroke: Color.fromHex('#a9a9a9'),
+    tableColumnsBorder: Color.fromHex('#cccccc').transparent(0.2)
 };
 const DefaultOptions = {
     keyboardSupport: true,
@@ -842,15 +870,15 @@ export class List {
         var _a;
         this.user = user;
         this._options = _options;
+        this.focus = new Trait('focused');
+        this.anchor = new Trait('anchor');
         this.eventBufferer = new EventBufferer();
         this._ariaLabel = '';
         this.disposables = new DisposableStore();
-        this.didJustPressContextMenuKey = false;
         this._onDidDispose = new Emitter();
         this.onDidDispose = this._onDidDispose.event;
         const role = this._options.accessibilityProvider && this._options.accessibilityProvider.getWidgetRole ? (_a = this._options.accessibilityProvider) === null || _a === void 0 ? void 0 : _a.getWidgetRole() : 'list';
         this.selection = new SelectionTrait(role !== 'listbox');
-        this.focus = new Trait('focused');
         mixin(_options, defaultStyles, false);
         const baseRenderers = [this.focus.renderer, this.selection.renderer];
         this.accessibilityProvider = _options.accessibilityProvider;
@@ -868,16 +896,18 @@ export class List {
             this.styleController = _options.styleController(this.view.domId);
         }
         else {
-            const styleElement = DOM.createStyleSheet(this.view.domNode);
+            const styleElement = createStyleSheet(this.view.domNode);
             this.styleController = new DefaultStyleController(styleElement, this.view.domId);
         }
         this.spliceable = new CombinedSpliceable([
             new TraitSpliceable(this.focus, this.view, _options.identityProvider),
             new TraitSpliceable(this.selection, this.view, _options.identityProvider),
+            new TraitSpliceable(this.anchor, this.view, _options.identityProvider),
             this.view
         ]);
         this.disposables.add(this.focus);
         this.disposables.add(this.selection);
+        this.disposables.add(this.anchor);
         this.disposables.add(this.view);
         this.disposables.add(this._onDidDispose);
         this.onDidFocus = Event.map(domEvent(this.view.domNode, 'focus', true), () => null);
@@ -917,31 +947,39 @@ export class List {
     get onMouseDown() { return this.view.onMouseDown; }
     get onTouchStart() { return this.view.onTouchStart; }
     get onTap() { return this.view.onTap; }
+    /**
+     * Possible context menu trigger events:
+     * - ContextMenu key
+     * - Shift F10
+     * - Ctrl Option Shift M (macOS with VoiceOver)
+     * - Mouse right click
+     */
     get onContextMenu() {
-        const fromKeydown = Event.chain(domEvent(this.view.domNode, 'keydown'))
+        let didJustPressContextMenuKey = false;
+        const fromKeyDown = Event.chain(domEvent(this.view.domNode, 'keydown'))
             .map(e => new StandardKeyboardEvent(e))
-            .filter(e => this.didJustPressContextMenuKey = e.keyCode === 58 /* ContextMenu */ || (e.shiftKey && e.keyCode === 68 /* F10 */))
-            .filter(e => { e.preventDefault(); e.stopPropagation(); return false; })
+            .filter(e => didJustPressContextMenuKey = e.keyCode === 58 /* ContextMenu */ || (e.shiftKey && e.keyCode === 68 /* F10 */))
+            .map(stopEvent)
+            .filter(() => false)
             .event;
-        const fromKeyup = Event.chain(domEvent(this.view.domNode, 'keyup'))
-            .filter(() => {
-            const didJustPressContextMenuKey = this.didJustPressContextMenuKey;
-            this.didJustPressContextMenuKey = false;
-            return didJustPressContextMenuKey;
-        })
-            .filter(() => this.getFocus().length > 0 && !!this.view.domElement(this.getFocus()[0]))
-            .map(browserEvent => {
-            const index = this.getFocus()[0];
-            const element = this.view.element(index);
-            const anchor = this.view.domElement(index);
+        const fromKeyUp = Event.chain(domEvent(this.view.domNode, 'keyup'))
+            .forEach(() => didJustPressContextMenuKey = false)
+            .map(e => new StandardKeyboardEvent(e))
+            .filter(e => e.keyCode === 58 /* ContextMenu */ || (e.shiftKey && e.keyCode === 68 /* F10 */))
+            .map(stopEvent)
+            .map(({ browserEvent }) => {
+            const focus = this.getFocus();
+            const index = focus.length ? focus[0] : undefined;
+            const element = typeof index !== 'undefined' ? this.view.element(index) : undefined;
+            const anchor = typeof index !== 'undefined' ? this.view.domElement(index) : this.view.domNode;
             return { index, element, anchor, browserEvent };
         })
             .event;
         const fromMouse = Event.chain(this.view.onContextMenu)
-            .filter(() => !this.didJustPressContextMenuKey)
-            .map(({ element, index, browserEvent }) => ({ element, index, anchor: { x: browserEvent.clientX + 1, y: browserEvent.clientY }, browserEvent }))
+            .filter(_ => !didJustPressContextMenuKey)
+            .map(({ element, index, browserEvent }) => ({ element, index, anchor: { x: browserEvent.pageX + 1, y: browserEvent.pageY }, browserEvent }))
             .event;
-        return Event.any(fromKeydown, fromKeyup, fromMouse);
+        return Event.any(fromKeyDown, fromKeyUp, fromMouse);
     }
     get onKeyDown() { return domEvent(this.view.domNode, 'keydown'); }
     createMouseController(options) {
@@ -995,7 +1033,7 @@ export class List {
         this.view.domNode.setAttribute('aria-label', value);
     }
     domFocus() {
-        this.view.domNode.focus();
+        this.view.domNode.focus({ preventScroll: true });
     }
     layout(height, width) {
         this.view.layout(height, width);
@@ -1014,6 +1052,19 @@ export class List {
     getSelectedElements() {
         return this.getSelection().map(i => this.view.element(i));
     }
+    setAnchor(index) {
+        if (typeof index === 'undefined') {
+            this.anchor.set([]);
+            return;
+        }
+        if (index < 0 || index >= this.length) {
+            throw new ListError(this.user, `Invalid index ${index}`);
+        }
+        this.anchor.set([index]);
+    }
+    getAnchor() {
+        return firstOrDefault(this.anchor.get(), undefined);
+    }
     setFocus(indexes, browserEvent) {
         for (const index of indexes) {
             if (index < 0 || index >= this.length) {
@@ -1043,56 +1094,64 @@ export class List {
         }
     }
     focusNextPage(browserEvent, filter) {
-        let lastPageIndex = this.view.indexAt(this.view.getScrollTop() + this.view.renderHeight);
-        lastPageIndex = lastPageIndex === 0 ? 0 : lastPageIndex - 1;
-        const lastPageElement = this.view.element(lastPageIndex);
-        const currentlyFocusedElement = this.getFocusedElements()[0];
-        if (currentlyFocusedElement !== lastPageElement) {
-            const lastGoodPageIndex = this.findPreviousIndex(lastPageIndex, false, filter);
-            if (lastGoodPageIndex > -1 && currentlyFocusedElement !== this.view.element(lastGoodPageIndex)) {
-                this.setFocus([lastGoodPageIndex], browserEvent);
+        return __awaiter(this, void 0, void 0, function* () {
+            let lastPageIndex = this.view.indexAt(this.view.getScrollTop() + this.view.renderHeight);
+            lastPageIndex = lastPageIndex === 0 ? 0 : lastPageIndex - 1;
+            const lastPageElement = this.view.element(lastPageIndex);
+            const currentlyFocusedElement = this.getFocusedElements()[0];
+            if (currentlyFocusedElement !== lastPageElement) {
+                const lastGoodPageIndex = this.findPreviousIndex(lastPageIndex, false, filter);
+                if (lastGoodPageIndex > -1 && currentlyFocusedElement !== this.view.element(lastGoodPageIndex)) {
+                    this.setFocus([lastGoodPageIndex], browserEvent);
+                }
+                else {
+                    this.setFocus([lastPageIndex], browserEvent);
+                }
             }
             else {
-                this.setFocus([lastPageIndex], browserEvent);
+                const previousScrollTop = this.view.getScrollTop();
+                this.view.setScrollTop(previousScrollTop + this.view.renderHeight - this.view.elementHeight(lastPageIndex));
+                if (this.view.getScrollTop() !== previousScrollTop) {
+                    this.setFocus([]);
+                    // Let the scroll event listener run
+                    yield timeout(0);
+                    yield this.focusNextPage(browserEvent, filter);
+                }
             }
-        }
-        else {
-            const previousScrollTop = this.view.getScrollTop();
-            this.view.setScrollTop(previousScrollTop + this.view.renderHeight - this.view.elementHeight(lastPageIndex));
-            if (this.view.getScrollTop() !== previousScrollTop) {
-                // Let the scroll event listener run
-                setTimeout(() => this.focusNextPage(browserEvent, filter), 0);
-            }
-        }
+        });
     }
     focusPreviousPage(browserEvent, filter) {
-        let firstPageIndex;
-        const scrollTop = this.view.getScrollTop();
-        if (scrollTop === 0) {
-            firstPageIndex = this.view.indexAt(scrollTop);
-        }
-        else {
-            firstPageIndex = this.view.indexAfter(scrollTop - 1);
-        }
-        const firstPageElement = this.view.element(firstPageIndex);
-        const currentlyFocusedElement = this.getFocusedElements()[0];
-        if (currentlyFocusedElement !== firstPageElement) {
-            const firstGoodPageIndex = this.findNextIndex(firstPageIndex, false, filter);
-            if (firstGoodPageIndex > -1 && currentlyFocusedElement !== this.view.element(firstGoodPageIndex)) {
-                this.setFocus([firstGoodPageIndex], browserEvent);
+        return __awaiter(this, void 0, void 0, function* () {
+            let firstPageIndex;
+            const scrollTop = this.view.getScrollTop();
+            if (scrollTop === 0) {
+                firstPageIndex = this.view.indexAt(scrollTop);
             }
             else {
-                this.setFocus([firstPageIndex], browserEvent);
+                firstPageIndex = this.view.indexAfter(scrollTop - 1);
             }
-        }
-        else {
-            const previousScrollTop = scrollTop;
-            this.view.setScrollTop(scrollTop - this.view.renderHeight);
-            if (this.view.getScrollTop() !== previousScrollTop) {
-                // Let the scroll event listener run
-                setTimeout(() => this.focusPreviousPage(browserEvent, filter), 0);
+            const firstPageElement = this.view.element(firstPageIndex);
+            const currentlyFocusedElement = this.getFocusedElements()[0];
+            if (currentlyFocusedElement !== firstPageElement) {
+                const firstGoodPageIndex = this.findNextIndex(firstPageIndex, false, filter);
+                if (firstGoodPageIndex > -1 && currentlyFocusedElement !== this.view.element(firstGoodPageIndex)) {
+                    this.setFocus([firstGoodPageIndex], browserEvent);
+                }
+                else {
+                    this.setFocus([firstPageIndex], browserEvent);
+                }
             }
-        }
+            else {
+                const previousScrollTop = scrollTop;
+                this.view.setScrollTop(scrollTop - this.view.renderHeight);
+                if (this.view.getScrollTop() !== previousScrollTop) {
+                    this.setFocus([]);
+                    // Let the scroll event listener run
+                    yield timeout(0);
+                    yield this.focusPreviousPage(browserEvent, filter);
+                }
+            }
+        });
     }
     focusLast(browserEvent, filter) {
         if (this.length === 0) {
@@ -1161,14 +1220,14 @@ export class List {
         }
         else {
             const viewItemBottom = elementTop + elementHeight;
-            const wrapperBottom = scrollTop + this.view.renderHeight;
-            if (elementTop < scrollTop && viewItemBottom >= wrapperBottom) {
+            const scrollBottom = scrollTop + this.view.renderHeight;
+            if (elementTop < scrollTop && viewItemBottom >= scrollBottom) {
                 // The element is already overflowing the viewport, no-op
             }
-            else if (elementTop < scrollTop) {
+            else if (elementTop < scrollTop || (viewItemBottom >= scrollBottom && elementHeight >= this.view.renderHeight)) {
                 this.view.setScrollTop(elementTop);
             }
-            else if (viewItemBottom >= wrapperBottom) {
+            else if (viewItemBottom >= scrollBottom) {
                 this.view.setScrollTop(viewItemBottom - this.view.renderHeight);
             }
         }
@@ -1202,7 +1261,7 @@ export class List {
     }
     _onFocusChange() {
         const focus = this.focus.get();
-        DOM.toggleClass(this.view.domNode, 'element-focused', focus.length > 0);
+        this.view.domNode.classList.toggle('element-focused', focus.length > 0);
         this.onDidChangeActiveDescendant();
     }
     onDidChangeActiveDescendant() {
@@ -1221,9 +1280,9 @@ export class List {
     }
     _onSelectionChange() {
         const selection = this.selection.get();
-        DOM.toggleClass(this.view.domNode, 'selection-none', selection.length === 0);
-        DOM.toggleClass(this.view.domNode, 'selection-single', selection.length === 1);
-        DOM.toggleClass(this.view.domNode, 'selection-multiple', selection.length > 1);
+        this.view.domNode.classList.toggle('selection-none', selection.length === 0);
+        this.view.domNode.classList.toggle('selection-single', selection.length === 1);
+        this.view.domNode.classList.toggle('selection-multiple', selection.length > 1);
     }
     dispose() {
         this._onDidDispose.fire();
