@@ -62,7 +62,7 @@ export class GlobalStyleSheet {
     }
 }
 let CodeEditorServiceImpl = class CodeEditorServiceImpl extends AbstractCodeEditorService {
-    constructor(themeService, styleSheet = null) {
+    constructor(styleSheet, themeService) {
         super();
         this._decorationOptionProviders = new Map();
         this._editorStyleSheets = new Map();
@@ -93,7 +93,7 @@ let CodeEditorServiceImpl = class CodeEditorServiceImpl extends AbstractCodeEdit
     _removeEditorStyleSheets(editorId) {
         this._editorStyleSheets.delete(editorId);
     }
-    registerDecorationType(key, options, parentTypeKey, editor) {
+    registerDecorationType(description, key, options, parentTypeKey, editor) {
         let provider = this._decorationOptionProviders.get(key);
         if (!provider) {
             const styleSheet = this._getOrCreateStyleSheet(editor);
@@ -104,12 +104,13 @@ let CodeEditorServiceImpl = class CodeEditorServiceImpl extends AbstractCodeEdit
                 options: options || Object.create(null)
             };
             if (!parentTypeKey) {
-                provider = new DecorationTypeOptionsProvider(this._themeService, styleSheet, providerArgs);
+                provider = new DecorationTypeOptionsProvider(description, this._themeService, styleSheet, providerArgs);
             }
             else {
                 provider = new DecorationSubTypeOptionsProvider(this._themeService, styleSheet, providerArgs);
             }
             this._decorationOptionProviders.set(key, provider);
+            this._onDecorationTypeRegistered.fire(key);
         }
         provider.refCount++;
     }
@@ -133,10 +134,10 @@ let CodeEditorServiceImpl = class CodeEditorServiceImpl extends AbstractCodeEdit
     }
 };
 CodeEditorServiceImpl = __decorate([
-    __param(0, IThemeService)
+    __param(1, IThemeService)
 ], CodeEditorServiceImpl);
 export { CodeEditorServiceImpl };
-class DecorationSubTypeOptionsProvider {
+export class DecorationSubTypeOptionsProvider {
     constructor(themeService, styleSheet, providerArgs) {
         this._styleSheet = styleSheet;
         this._styleSheet.ref();
@@ -167,9 +168,10 @@ class DecorationSubTypeOptionsProvider {
         this._styleSheet.unref();
     }
 }
-class DecorationTypeOptionsProvider {
-    constructor(themeService, styleSheet, providerArgs) {
+export class DecorationTypeOptionsProvider {
+    constructor(description, themeService, styleSheet, providerArgs) {
         this._disposables = new DisposableStore();
+        this.description = description;
         this._styleSheet = styleSheet;
         this._styleSheet.ref();
         this.refCount = 0;
@@ -217,6 +219,7 @@ class DecorationTypeOptionsProvider {
             return this;
         }
         return {
+            description: this.description,
             inlineClassName: this.inlineClassName,
             beforeContentClassName: this.beforeContentClassName,
             afterContentClassName: this.afterContentClassName,
@@ -232,7 +235,7 @@ class DecorationTypeOptionsProvider {
         this._styleSheet.unref();
     }
 }
-const _CSS_MAP = {
+export const _CSS_MAP = {
     color: 'color:{0} !important;',
     opacity: 'opacity:{0};',
     backgroundColor: 'background-color:{0};',
@@ -248,6 +251,8 @@ const _CSS_MAP = {
     borderWidth: 'border-width:{0};',
     fontStyle: 'font-style:{0};',
     fontWeight: 'font-weight:{0};',
+    fontSize: 'font-size:{0};',
+    fontFamily: 'font-family:{0};',
     textDecoration: 'text-decoration:{0};',
     cursor: 'cursor:{0};',
     letterSpacing: 'letter-spacing:{0};',
@@ -256,6 +261,7 @@ const _CSS_MAP = {
     contentText: 'content:\'{0}\';',
     contentIconPath: 'content:{0};',
     margin: 'margin:{0};',
+    padding: 'padding:{0};',
     width: 'width:{0};',
     height: 'height:{0};'
 };
@@ -400,7 +406,7 @@ class DecorationCSSRules {
                 const escaped = truncated.replace(/['\\]/g, '\\$&');
                 cssTextArr.push(strings.format(_CSS_MAP.contentText, escaped));
             }
-            this.collectCSSText(opts, ['fontStyle', 'fontWeight', 'textDecoration', 'color', 'opacity', 'backgroundColor', 'margin'], cssTextArr);
+            this.collectCSSText(opts, ['fontStyle', 'fontWeight', 'fontSize', 'fontFamily', 'textDecoration', 'color', 'opacity', 'backgroundColor', 'margin', 'padding'], cssTextArr);
             if (this.collectCSSText(opts, ['width', 'height'], cssTextArr)) {
                 cssTextArr.push('display:inline-block;');
             }
