@@ -18,35 +18,35 @@ test('GET errors and reconnect with pipelining 1', (t) => {
     res.socket.destroy()
 
     server.once('request', (req, res) => {
-      t.strictEqual('/', req.url)
-      t.strictEqual('GET', req.method)
+      t.equal('/', req.url)
+      t.equal('GET', req.method)
       res.setHeader('content-type', 'text/plain')
       res.end('hello')
     })
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`, {
       pipelining: 1
     })
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     client.request({ path: '/', method: 'GET', idempotent: false, opaque: 'asd' }, (err, data) => {
       t.ok(err instanceof Error) // we are expecting an error
-      t.strictEqual(data.opaque, 'asd')
+      t.equal(data.opaque, 'asd')
     })
 
     client.request({ path: '/', method: 'GET' }, (err, { statusCode, headers, body }) => {
       t.error(err)
-      t.strictEqual(statusCode, 200)
-      t.strictEqual(headers['content-type'], 'text/plain')
+      t.equal(statusCode, 200)
+      t.equal(headers['content-type'], 'text/plain')
       const bufs = []
       body.on('data', (buf) => {
         bufs.push(buf)
       })
       body.on('end', () => {
-        t.strictEqual('hello', Buffer.concat(bufs).toString('utf8'))
+        t.equal('hello', Buffer.concat(bufs).toString('utf8'))
       })
     })
   })
@@ -69,39 +69,39 @@ test('GET errors and reconnect with pipelining 3', (t) => {
         res.socket.destroy()
       }
     } else {
-      t.strictEqual('/', req.url)
-      t.strictEqual('GET', req.method)
+      t.equal('/', req.url)
+      t.equal('GET', req.method)
       res.setHeader('content-type', 'text/plain')
       res.end('hello')
     }
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`, {
       pipelining: 3
     })
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     // all of these will error
     for (let i = 0; i < 3; i++) {
       client.request({ path: '/', method: 'GET', idempotent: false, opaque: 'asd' }, (err, data) => {
         t.ok(err instanceof Error) // we are expecting an error
-        t.strictEqual(data.opaque, 'asd')
+        t.equal(data.opaque, 'asd')
       })
     }
 
     // this will be queued up
     client.request({ path: '/', method: 'GET', idempotent: false }, (err, { statusCode, headers, body }) => {
       t.error(err)
-      t.strictEqual(statusCode, 200)
-      t.strictEqual(headers['content-type'], 'text/plain')
+      t.equal(statusCode, 200)
+      t.equal(headers['content-type'], 'text/plain')
       const bufs = []
       body.on('data', (buf) => {
         bufs.push(buf)
       })
       body.on('end', () => {
-        t.strictEqual('hello', Buffer.concat(bufs).toString('utf8'))
+        t.equal('hello', Buffer.concat(bufs).toString('utf8'))
       })
     })
   })
@@ -112,9 +112,9 @@ test('POST with a stream that errors and pipelining 1 should reconnect', (t) =>
 
   const server = createServer()
   server.once('request', (req, res) => {
-    t.strictEqual('/', req.url)
-    t.strictEqual('POST', req.method)
-    t.strictEqual('42', req.headers['content-length'])
+    t.equal('/', req.url)
+    t.equal('POST', req.method)
+    t.equal('42', req.headers['content-length'])
 
     const bufs = []
     req.on('data', (buf) => {
@@ -124,21 +124,21 @@ test('POST with a stream that errors and pipelining 1 should reconnect', (t) =>
     req.on('aborted', () => {
       // we will abruptly close the connection here
       // but this will still end
-      t.strictEqual('a string', Buffer.concat(bufs).toString('utf8'))
+      t.equal('a string', Buffer.concat(bufs).toString('utf8'))
     })
 
     server.once('request', (req, res) => {
-      t.strictEqual('/', req.url)
-      t.strictEqual('GET', req.method)
+      t.equal('/', req.url)
+      t.equal('GET', req.method)
       res.setHeader('content-type', 'text/plain')
       res.end('hello')
     })
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     client.request({
       path: '/',
@@ -155,21 +155,21 @@ test('POST with a stream that errors and pipelining 1 should reconnect', (t) =>
         }
       })
     }, (err, data) => {
-      t.strictEqual(err.message, 'kaboom')
-      t.strictEqual(data.opaque, 'asd')
+      t.equal(err.message, 'kaboom')
+      t.equal(data.opaque, 'asd')
     })
 
     // this will be queued up
     client.request({ path: '/', method: 'GET', idempotent: false }, (err, { statusCode, headers, body }) => {
       t.error(err)
-      t.strictEqual(statusCode, 200)
-      t.strictEqual(headers['content-type'], 'text/plain')
+      t.equal(statusCode, 200)
+      t.equal(headers['content-type'], 'text/plain')
       const bufs = []
       body.on('data', (buf) => {
         bufs.push(buf)
       })
       body.on('end', () => {
-        t.strictEqual('hello', Buffer.concat(bufs).toString('utf8'))
+        t.equal('hello', Buffer.concat(bufs).toString('utf8'))
       })
     })
   })
@@ -180,9 +180,9 @@ test('POST with chunked encoding that errors and pipelining 1 should reconnect',
 
   const server = createServer()
   server.once('request', (req, res) => {
-    t.strictEqual('/', req.url)
-    t.strictEqual('POST', req.method)
-    t.strictEqual(req.headers['content-length'], undefined)
+    t.equal('/', req.url)
+    t.equal('POST', req.method)
+    t.equal(req.headers['content-length'], undefined)
 
     const bufs = []
     req.on('data', (buf) => {
@@ -192,21 +192,21 @@ test('POST with chunked encoding that errors and pipelining 1 should reconnect',
     req.on('aborted', () => {
       // we will abruptly close the connection here
       // but this will still end
-      t.strictEqual('a string', Buffer.concat(bufs).toString('utf8'))
+      t.equal('a string', Buffer.concat(bufs).toString('utf8'))
     })
 
     server.once('request', (req, res) => {
-      t.strictEqual('/', req.url)
-      t.strictEqual('GET', req.method)
+      t.equal('/', req.url)
+      t.equal('GET', req.method)
       res.setHeader('content-type', 'text/plain')
       res.end('hello')
     })
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     client.request({
       path: '/',
@@ -219,21 +219,21 @@ test('POST with chunked encoding that errors and pipelining 1 should reconnect',
         }
       })
     }, (err, data) => {
-      t.strictEqual(err.message, 'kaboom')
-      t.strictEqual(data.opaque, 'asd')
+      t.equal(err.message, 'kaboom')
+      t.equal(data.opaque, 'asd')
     })
 
     // this will be queued up
     client.request({ path: '/', method: 'GET' }, (err, { statusCode, headers, body }) => {
       t.error(err)
-      t.strictEqual(statusCode, 200)
-      t.strictEqual(headers['content-type'], 'text/plain')
+      t.equal(statusCode, 200)
+      t.equal(headers['content-type'], 'text/plain')
       const bufs = []
       body.on('data', (buf) => {
         bufs.push(buf)
       })
       body.on('end', () => {
-        t.strictEqual('hello', Buffer.concat(bufs).toString('utf8'))
+        t.equal('hello', Buffer.concat(bufs).toString('utf8'))
       })
     })
   })
@@ -242,150 +242,172 @@ test('POST with chunked encoding that errors and pipelining 1 should reconnect',
 test('invalid options throws', (t) => {
   try {
     new Client({ port: 'foobar' }) // eslint-disable-line
+    t.fail()
   } catch (err) {
     t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid port')
+    t.equal(err.message, 'invalid port')
   }
 
   try {
     new Client(new URL('http://asd:200/somepath')) // eslint-disable-line
+    t.fail()
   } catch (err) {
     t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid url')
+    t.equal(err.message, 'invalid url')
   }
 
   try {
     new Client(new URL('http://asd:200?q=asd')) // eslint-disable-line
+    t.fail()
   } catch (err) {
     t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid url')
+    t.equal(err.message, 'invalid url')
   }
 
   try {
     new Client(new URL('http://asd:200#asd')) // eslint-disable-line
+    t.fail()
   } catch (err) {
     t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid url')
+    t.equal(err.message, 'invalid url')
   }
 
   try {
     new Client(new URL('http://localhost:200'), { // eslint-disable-line
       socketPath: 1
     })
+    t.fail()
   } catch (err) {
     t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid socketPath')
+    t.equal(err.message, 'invalid socketPath')
   }
 
   try {
     new Client(new URL('http://localhost:200'), { // eslint-disable-line
-      headersTimeout: 'asd'
+      keepAliveTimeout: 'asd'
     }) // eslint-disable-line
+    t.fail()
   } catch (err) {
     t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid headersTimeout')
-  }
-
-  try {
-    new Client(new URL('http://localhost:200'), { // eslint-disable-line
-      idleTimeout: 'asd'
-    }) // eslint-disable-line
-  } catch (err) {
-    t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid idleTimeout')
+    t.equal(err.message, 'invalid keepAliveTimeout')
   }
 
   try {
     new Client(new URL('http://localhost:200'), { // eslint-disable-line
       keepAliveMaxTimeout: 'asd'
     }) // eslint-disable-line
+    t.fail()
   } catch (err) {
     t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid keepAliveMaxTimeout')
+    t.equal(err.message, 'invalid keepAliveMaxTimeout')
   }
 
   try {
     new Client(new URL('http://localhost:200'), { // eslint-disable-line
       keepAliveMaxTimeout: 0
     }) // eslint-disable-line
+    t.fail()
   } catch (err) {
     t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid keepAliveMaxTimeout')
+    t.equal(err.message, 'invalid keepAliveMaxTimeout')
   }
 
   try {
     new Client(new URL('http://localhost:200'), { // eslint-disable-line
       keepAliveTimeoutThreshold: 'asd'
     }) // eslint-disable-line
+    t.fail()
   } catch (err) {
     t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid keepAliveTimeoutThreshold')
-  }
-
-  try {
-    new Client(new URL('http://localhost:200'), { // eslint-disable-line
-      socketTimeout: 'asd'
-    })
-  } catch (err) {
-    t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid socketTimeout')
+    t.equal(err.message, 'invalid keepAliveTimeoutThreshold')
   }
 
   try {
     new Client({ // eslint-disable-line
       protocol: 'asd'
     })
+    t.fail()
   } catch (err) {
     t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid protocol')
+    t.equal(err.message, 'invalid protocol')
   }
 
   try {
     new Client({ // eslint-disable-line
       hostname: 1
     })
+    t.fail()
   } catch (err) {
     t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid hostname')
+    t.equal(err.message, 'invalid hostname')
   }
 
   try {
     new Client(new URL('http://localhost:200'), { // eslint-disable-line
       maxHeaderSize: 'asd'
     })
+    t.fail()
   } catch (err) {
     t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid maxHeaderSize')
+    t.equal(err.message, 'invalid maxHeaderSize')
   }
 
   try {
     new Client(1) // eslint-disable-line
+    t.fail()
   } catch (err) {
     t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid url')
+    t.equal(err.message, 'invalid url')
   }
 
   try {
-    const client = new Client(new URL('http://localhost:200'))
+    const client = new Client(new URL('http://localhost:200')) // eslint-disable-line
     client.destroy(null, null)
+    t.fail()
   } catch (err) {
     t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid callback')
+    t.equal(err.message, 'invalid callback')
   }
 
   try {
-    const client = new Client(new URL('http://localhost:200'))
-    client.close(null)
+    const client = new Client(new URL('http://localhost:200')) // eslint-disable-line
+    client.close(null, null)
+    t.fail()
   } catch (err) {
     t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid callback')
+    t.equal(err.message, 'invalid callback')
   }
 
   try {
-    new Client(new URL('http://localhost:200'), { keepAlive: 'true' }) // eslint-disable-line
+    new Client(new URL('http://localhost:200'), { maxKeepAliveTimeout: 1e3 }) // eslint-disable-line
+    t.fail()
   } catch (err) {
     t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid keepAlive')
+    t.equal(err.message, 'unsupported maxKeepAliveTimeout, use keepAliveMaxTimeout instead')
+  }
+
+  try {
+    new Client(new URL('http://localhost:200'), { keepAlive: false }) // eslint-disable-line
+    t.fail()
+  } catch (err) {
+    t.ok(err instanceof errors.InvalidArgumentError)
+    t.equal(err.message, 'unsupported keepAlive, use pipelining=0 instead')
+  }
+
+  try {
+    new Client(new URL('http://localhost:200'), { idleTimeout: 30e3 }) // eslint-disable-line
+    t.fail()
+  } catch (err) {
+    t.ok(err instanceof errors.InvalidArgumentError)
+    t.equal(err.message, 'unsupported idleTimeout, use keepAliveTimeout instead')
+  }
+
+  try {
+    new Client(new URL('http://localhost:200'), { socketTimeout: 30e3 }) // eslint-disable-line
+    t.fail()
+  } catch (err) {
+    t.ok(err instanceof errors.InvalidArgumentError)
+    t.equal(err.message, 'unsupported socketTimeout, use headersTimeout & bodyTimeout instead')
   }
 
   t.end()
@@ -400,11 +422,11 @@ test('POST which fails should error response', (t) => {
       res.destroy()
     })
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     function checkError (err) {
       // Different platforms error with different codes...
@@ -466,16 +488,16 @@ test('client destroy cleanup', (t) => {
       })
     })
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     const body = new Readable({ read () {} })
     body.push('asd')
     body.on('error', (err) => {
-      t.strictEqual(err, _err)
+      t.equal(err, _err)
     })
 
     client.request({
@@ -483,7 +505,7 @@ test('client destroy cleanup', (t) => {
       method: 'POST',
       body
     }, (err, data) => {
-      t.strictEqual(err, _err)
+      t.equal(err, _err)
     })
   })
 })
@@ -498,11 +520,11 @@ test('GET errors body', (t) => {
       res.destroy()
     }, 19)
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     client.request({ path: '/', method: 'GET' }, (err, { statusCode, headers, body }) => {
       t.error(err)
@@ -520,11 +542,11 @@ test('validate request body', (t) => {
   const server = createServer((req, res) => {
     res.end('asd')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     client.request({
       path: '/',
@@ -586,11 +608,11 @@ test('parser error', (t) => {
   server.once('connection', (socket) => {
     socket.write('asd\n\r213123')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     client.request({ path: '/', method: 'GET' }, (err) => {
       t.ok(err)
@@ -607,11 +629,11 @@ test('socket fail while writing request body', (t) => {
   const server = createServer()
   server.once('request', (req, res) => {
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     const body = new Readable({ read () {} })
     body.push('asd')
@@ -642,13 +664,13 @@ test('socket fail while ending request body', (t) => {
   server.once('request', (req, res) => {
     res.end()
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`, {
       pipelining: 2
     })
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     const _err = new Error('kaboom')
     client.on('connect', () => {
@@ -663,7 +685,7 @@ test('socket fail while ending request body', (t) => {
       method: 'POST',
       body
     }, (err) => {
-      t.strictEqual(err, _err)
+      t.equal(err, _err)
     })
     client.close((err) => {
       t.error(err)
@@ -681,13 +703,13 @@ test('queued request should not fail on socket destroy', (t) => {
   server.on('request', (req, res) => {
     res.end()
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`, {
       pipelining: 1
     })
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     client.request({
       path: '/',
@@ -718,13 +740,13 @@ test('queued request should fail on client destroy', (t) => {
   server.on('request', (req, res) => {
     res.end()
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`, {
       pipelining: 1
     })
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     let requestErrored = false
     client.request({
@@ -738,7 +760,7 @@ test('queued request should fail on client destroy', (t) => {
         })
       client.destroy((err) => {
         t.error(err)
-        t.strictEqual(requestErrored, true)
+        t.equal(requestErrored, true)
       })
     })
     client.request({
@@ -748,7 +770,7 @@ test('queued request should fail on client destroy', (t) => {
     }, (err, data) => {
       requestErrored = true
       t.ok(err)
-      t.strictEqual(data.opaque, 'asd')
+      t.equal(data.opaque, 'asd')
     })
   })
 })
@@ -760,13 +782,13 @@ test('retry idempotent inflight', (t) => {
   server.on('request', (req, res) => {
     res.end()
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`, {
       pipelining: 3
     })
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     client.request({
       path: '/',
@@ -847,11 +869,11 @@ test('CONNECT throws in next tick', (t) => {
   server.on('request', (req, res) => {
     res.end()
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     client.request({
       path: '/',
@@ -866,7 +888,7 @@ test('CONNECT throws in next tick', (t) => {
             method: 'CONNECT'
           }, (err) => {
             t.ok(err)
-            t.strictDeepEqual(ticked, true)
+            t.strictSame(ticked, true)
           })
           ticked = true
         })
@@ -883,18 +905,18 @@ test('invalid signal', (t) => {
 
   let ticked = false
   client.request({ path: '/', method: 'GET', signal: {}, opaque: 'asd' }, (err, { opaque }) => {
-    t.strictEqual(ticked, true)
-    t.strictEqual(opaque, 'asd')
+    t.equal(ticked, true)
+    t.equal(opaque, 'asd')
     t.ok(err instanceof errors.InvalidArgumentError)
   })
   client.pipeline({ path: '/', method: 'GET', signal: {} }, () => {})
     .on('error', (err) => {
-      t.strictEqual(ticked, true)
+      t.equal(ticked, true)
       t.ok(err instanceof errors.InvalidArgumentError)
     })
   client.stream({ path: '/', method: 'GET', signal: {}, opaque: 'asd' }, () => {}, (err, { opaque }) => {
-    t.strictEqual(ticked, true)
-    t.strictEqual(opaque, 'asd')
+    t.equal(ticked, true)
+    t.equal(opaque, 'asd')
     t.ok(err instanceof errors.InvalidArgumentError)
   })
   ticked = true
@@ -907,11 +929,11 @@ test('invalid body chunk does not crash', (t) => {
   server.on('request', (req, res) => {
     res.end()
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     client.request({
       path: '/',
@@ -923,7 +945,7 @@ test('invalid body chunk does not crash', (t) => {
       }),
       method: 'GET'
     }, (err) => {
-      t.strictEqual(err.code, 'ERR_INVALID_ARG_TYPE')
+      t.equal(err.code, 'ERR_INVALID_ARG_TYPE')
     })
   })
 })
@@ -931,7 +953,7 @@ test('invalid body chunk does not crash', (t) => {
 test('socket errors', t => {
   t.plan(2)
   const client = new Client('http://localhost:5554')
-  t.tearDown(client.destroy.bind(client))
+  t.teardown(client.destroy.bind(client))
 
   client.request({ path: '/', method: 'GET' }, (err, data) => {
     t.ok(err)
