@@ -10,7 +10,7 @@ const instance = Fastify()
 instance.register(From)
 
 t.plan(9)
-t.tearDown(instance.close.bind(instance))
+t.teardown(instance.close.bind(instance))
 
 const target = http.createServer((req, res) => {
   t.pass('request proxied')
@@ -22,7 +22,7 @@ const target = http.createServer((req, res) => {
     data += d
   })
   req.on('end', () => {
-    t.deepEqual(JSON.parse(data), { hello: 'world' })
+    t.same(JSON.parse(data), { hello: 'world' })
     res.statusCode = 200
     res.setHeader('content-type', 'application/json')
     res.end(JSON.stringify({ something: 'else' }))
@@ -33,7 +33,7 @@ instance.post('/', (request, reply) => {
   reply.from(`http://localhost:${target.address().port}`)
 })
 
-t.tearDown(target.close.bind(target))
+t.teardown(target.close.bind(target))
 
 instance.listen(0, (err) => {
   t.error(err)
@@ -53,7 +53,7 @@ instance.listen(0, (err) => {
     }, (err, res, data) => {
       t.error(err)
       t.equal(res.headers['content-type'], 'application/json')
-      t.deepEqual(JSON.parse(data.toString()), { something: 'else' })
+      t.same(JSON.parse(data.toString()), { something: 'else' })
     })
   })
 })
