@@ -30,8 +30,8 @@ fastify.listen(0, err => {
     const url = `http://localhost:${fastify.server.address().port}`
     const res = await h2url.concat({ url, method: 'UNKNOWN_METHOD' })
 
-    t.strictEqual(res.headers[':status'], 404)
-    t.deepEqual(JSON.parse(res.body), {
+    t.equal(res.headers[':status'], 404)
+    t.same(JSON.parse(res.body), {
       statusCode: 404,
       error: 'Not Found',
       message: 'Not Found'
