@@ -9,7 +9,7 @@ const get = require('simple-get').concat
 const instance = Fastify()
 
 t.plan(6)
-t.tearDown(instance.close.bind(instance))
+t.teardown(instance.close.bind(instance))
 
 const target = http.createServer((req, res) => {
   t.fail('this should never get called')
@@ -20,12 +20,12 @@ instance.get('/', (request, reply) => {
   try {
     reply.from(null, { body: 'this is the new body' })
   } catch (e) {
-    t.strictEqual(e.message, 'Rewriting the body when doing a GET is not allowed')
+    t.equal(e.message, 'Rewriting the body when doing a GET is not allowed')
     reply.send('hello world')
   }
 })
 
-t.tearDown(target.close.bind(target))
+t.teardown(target.close.bind(target))
 
 target.listen(0, (err) => {
   t.error(err)
